@@ -31,6 +31,8 @@ func TestSourcesWithoutKeys(t *testing.T) {
 		"waybackarchive", // Fails randomly
 		"alienvault",     // 503 Service Temporarily Unavailable
 		"digitorus",      // failing with "Failed to retrieve certificate"
+		"dnsdumpster",    // failing with "unexpected status code 403 received"
+		"anubis",         // failing with "too many redirects"
 	}
 
 	domain := "hackerone.com"
