@@ -48,11 +48,11 @@ func (s *Source) Run(ctx context.Context, domain string, session *subscraping.Se
 			if err != nil {
 				results <- subscraping.Result{Source: s.Name(), Type: subscraping.Error, Error: err}
 				s.errors++
-				resp.Body.Close()
+				session.DiscardHTTPResponse(resp)
 				return
 			}
 
-			resp.Body.Close()
+			session.DiscardHTTPResponse(resp)
 
 			src := string(body)
 			for _, subdomain := range session.Extractor.Extract(src) {
